"use strict";
themeManager.init();

const spy = document.getElementById("betLabels")
spy.addEventListener("keydown", function (event) {
  if (event.key == "Enter") calc();
})

var csInterface = new CSInterface ();

evalFile ("json2.js");
evalFile ("main.jsx");
evalFile ("analyzer.jsx");
function evalFile (fileName) {
    var extensionPath = csInterface.getSystemPath (SystemPath.EXTENSION) + "/jsx/";
    csInterface.evalScript ('$.evalFile("' + extensionPath + fileName + '")');
}

var preferences = loadPrefs();
setPrefs(preferences);

function setPrefs(prefs){
	document.getElementById("betRowsDef").value = prefs.betRowsDef;
	document.getElementById("betLabelsDef").value = prefs.betLabelsDef;
	document.getElementById("rowsMax").value = prefs.rowsMax;
	document.getElementById("webWidthMax").value = prefs.webWidthMax;
	document.getElementById("reilWidth").value = prefs.reilWidth;
	document.getElementById("radiusDef").value = prefs.radiusDef;
	document.getElementById("rightIndent").value = prefs.rightIndent;
	document.getElementById("topIndentDef").value = prefs.topIndentDef;
	document.getElementById("delSwatches").checked = prefs.delSwatches;
	document.getElementById("delGraphicStyles").checked = prefs.delGraphicStyles;
	document.getElementById("tabSortDef").value = prefs.tabSortDef;
	document.getElementById("rolls").value = prefs.rolls;

	document.getElementById("betLabels").value = prefs.betLabelsDef;
	document.getElementById("betRows").value = prefs.betRowsDef;
	document.getElementById("topIndent").value = prefs.topIndentDef;
}

function getPrefs(){
	var prefs = new Object();
	prefs.betRowsDef = document.getElementById("betRowsDef").value;
	prefs.betLabelsDef = document.getElementById("betLabelsDef").value;
	prefs.rowsMax = document.getElementById("rowsMax").value;
	prefs.webWidthMax = document.getElementById("webWidthMax").value;
	prefs.reilWidth = document.getElementById("reilWidth").value;
	prefs.radiusDef = document.getElementById("radiusDef").value;
	prefs.rightIndent = document.getElementById("rightIndent").value;
	prefs.topIndentDef = document.getElementById("topIndentDef").value;
	prefs.delSwatches = document.getElementById("delSwatches").checked;
	prefs.delGraphicStyles = document.getElementById("delGraphicStyles").checked;
	prefs.tabSortDef = document.getElementById("tabSortDef").value;
	prefs.rolls = document.getElementById("rolls").value.split(',');
	return prefs;
}

function getPrefsDefault(){
	var prefs = new Object();
	prefs.betRowsDef = 3;
	prefs.betLabelsDef = 2;
	prefs.rowsMax = 15;
	prefs.webWidthMax = 330;
	prefs.reilWidth = 3; 
	prefs.radiusDef = 0.6;
	prefs.rightIndent = 10;
	prefs.topIndentDef = 2;
	prefs.delSwatches = true;
	prefs.delGraphicStyles = true;
	prefs.tabSortDef = 0;
	prefs.rolls = [96, 98, 100, 102, 104, 106, 108, 110];
	return prefs;
}

function loadPrefs(){
	var prefs = new Object();
	if (JSON.parse (localStorage.getItem ("prefs")) != null) {
        prefs = JSON.parse (localStorage.getItem ("prefs"))
    }
	else{
		prefs = getPrefsDefault();
	}
	return prefs;
}

function savePrefs(prefs){
	localStorage.setItem ("prefs", JSON.stringify (prefs));
}

function calc() {
	evalScript("app.documents.length", function(result) {
		if (result == 0) {
			location.reload();
			return;
		}
		evalScript("app.activeDocument.pathItems.length", function(result) {
			if (result == 0) {
				location.reload();
				return;
			}
			csInterface.evalScript ('getSize(' + JSON.stringify (preferences) + ', true);', function(result){
			var c = JSON.parse(result);
			document.getElementById("lblRadius").value = c.minR;
			if (c.minR < preferences.radiusDef){
				document.getElementById("lblRadius").style.border = '1px solid #ff0000'; 
			}
			else{
				document.getElementById("lblRadius").style = ".input";
			}
			document.getElementById("lblType").value = c.form;
			document.getElementById("acuteCornersCount").value = c.acuteCornersCount;
			document.getElementById("badArcCount").value = c.badArcCount;
			calcRoll(c.height, c.width, preferences);
			});
		});
	});
};

function Draw(rows, labels, betLabels, rollItem, raport, rotate) {
	preferences = getPrefs();
	preferences.rows = rows;
	preferences.labels = labels;
	preferences.betLabels = betLabels;
	preferences.rollItem = rollItem;
	preferences.raport = raport;
	preferences.rotate = rotate;
	preferences.betRows = document.getElementById("betRows").value;
	preferences.width = document.getElementById("lblWidth").value;
	preferences.height = document.getElementById("lblHeight").value;
	preferences.semirotary = document.getElementById("chkSemirotary").checked;
	preferences.flat = document.getElementById("chkFlat").checked;
	preferences.topIndent = document.getElementById("topIndent").value;
	preferences.radius = document.getElementById("lblRadius").value;

	if (preferences.semirotary || preferences.flat){
		preferences.labels = document.getElementById("lebelsCount").value;
		preferences.semirotary = true;
	}

	var tmp = document.getElementById("lblType").value;
	document.getElementById("lblType").value = preferences.width + 'x' + preferences.height;
	document.getElementById("lblType").select();
	var result = document.execCommand('copy');
	document.getElementById("lblType").value = tmp;

	evalScript("create("  + JSON.stringify (preferences) + ")", function(result) {});
	
}

function analyze() {
	csInterface.evalScript ('getSize(' + JSON.stringify (preferences) + ', false);', function(result){
		var c = JSON.parse(result);
		document.getElementById("minRadius").value = c.minR;
		if (c.minR < preferences.radiusDef){
			document.getElementById("minRadius").style.border = '1px solid #ff0000'; 
		}
		else{
			document.getElementById("minRadius").style = ".input";
		}
		document.getElementById("lblType").value = c.form;
		document.getElementById("acuteCornersCount").value = c.acuteCornersCount;
		document.getElementById("badArcCount").value = c.badArcCount;
	});
}

function evalScript(script, callback) {
    csInterface.evalScript(script, callback);
}
function semirotaryVisible(){
	if (document.getElementById("chkSemirotary").checked || document.getElementById("chkFlat").checked){
		addRule("hostStyle", ".semirotaryVisible", "visibility:" + "visible");
	}
	else{
		addRule("hostStyle", ".semirotaryVisible", "visibility:" + "hidden");
	}
}
function addRule(stylesheetId, selector, rule) {
	var stylesheet = document.getElementById(stylesheetId);
	
	if (stylesheet) {
		stylesheet = stylesheet.sheet;
		if (stylesheet.addRule) {
			stylesheet.addRule(selector, rule);
		} else if (stylesheet.insertRule) {
			stylesheet.insertRule(selector + " { " + rule + " }", stylesheet.cssRules.length);
		}
	}
}
function resizePanel(){
	var height = document.body.scrollHeight + 25,
	width = document.body.scrollWidth + 10;
	csInterface.resizeContent(width, height);
}

$("#tabDrawing").click(function() {
	document.getElementById('tabDrawing').className = 'tabButton tabButtonActive';
	document.getElementById('mainPage').style.display = 'inline-block'; 
	document.getElementById('setupPage').style.display = 'none';
	document.getElementById('cornersPage').style.display = 'none'; 
	document.getElementById('tabCorners').className = 'tabButton';
	document.getElementById('tabSetup').className = 'tabButton';

	if (!(document.getElementById('chkRotary').checked || document.getElementById('chkSemirotary').checked || document.getElementById('chkFlat').checked)){
		document.getElementById('chkRotary').checked = true;
	}
	calc();
})
$("#tabSetup").click(function() {
	document.getElementById('tabSetup').className = 'tabButton tabButtonActive';
	document.getElementById('mainPage').style.display = 'none'; 
	document.getElementById('cornersPage').style.display = 'none'; 
	document.getElementById('setupPage').style.display = 'inline-block';
	document.getElementById('tabCorners').className = 'tabButton';
	document.getElementById('tabDrawing').className = 'tabButton';
	// preferences = loadPrefs();
	// setPrefs(preferences);
})
$("#tabCorners").click(function() {
	document.getElementById('tabCorners').className = 'tabButton tabButtonActive';
	document.getElementById('mainPage').style.display = 'none'; 
	document.getElementById('setupPage').style.display = 'none'; 
	document.getElementById('cornersPage').style.display = 'inline-block';
	document.getElementById('tabSetup').className = 'tabButton';
	document.getElementById('tabDrawing').className = 'tabButton';
	preferences = loadPrefs();
	setPrefs(preferences);
	analyze();
})
$("#chkRotary").click(function() {
	semirotaryVisible();
	calc();
})
$("#chkSemirotary").click(function() {
	semirotaryVisible();
	calc();
})
$("#chkFlat").click(function() {
	semirotaryVisible();
	calc();
})
$("#betLabels").click(function() {
	calc();
})
$("#cancelPrefs").click(function() {
	preferences = loadPrefs();
	setPrefs(preferences);
})
$("#savePrefs").click(function() {
	preferences = getPrefs();
	savePrefs(preferences);
	setPrefs(preferences);
})
$("#defaultPrefs").click(function() {
	preferences = getPrefsDefault();
	setPrefs(preferences);
})
$("#reloadButton").click(function() {
	location.reload();
})
$("#fitButton").click(function() {
	resizePanel();
})
$("#showCorners").click(function() {
	csInterface.evalScript ('showCorners(' + preferences.radiusDef + ');', function(result){});
})
$("#showArcs").click(function() {
	csInterface.evalScript ('showArcs(' + preferences.radiusDef + ');', function(result){});
})
$("#analyze").click(function() {
	analyze();
})